pub fn fingerprint(rows: &[RowMap]) -> FingerprintExpand description
Compute a SHA-256 fingerprint of a table’s row content.
Algorithm:
- Each row is serialised to a canonical JSON string (keys sorted by
BTreeMap— already guaranteed byRowMap). - Rows are sorted lexicographically by their JSON representation so the fingerprint is stable regardless of the order rows are returned by the DB.
- All row strings are joined with
\nand hashed with SHA-256.
An empty table produces a well-defined fingerprint (hash of empty string).